# !/usr/bin/python
# -*- coding: utf-8 -*-

# Glitter Toolkit

__authors__ = ["Jan Jokela <janjokela@gmail.com>"]
__licenses__ = ["LICENSE.LGPL"]
__description__ = "Tests for the video widget"

import os
import sys

# Change sys path to glitter path
glitter_path = os.path.split(sys.path[0])[0]
sys.path[0] = glitter_path

from window import Window

import gtk

from frame import Frame
from box import HBox
from box import VBox
from image import Image
from toolbar import Toolbar
from floating_button import FloatingButton
from slider import Slider
from video import Video

# Importing glitter.video messes up sys.path because in its turn, it import gst
# which messes up sys.path
glitter_path = os.path.split(sys.path[0])[0]
sys.path[0] = glitter_path

class VideoPlayer(object):
    """ Tests for the video widget """
    
    def __init__(self, video_uri, aspect_ratio):
    
        self.video_uri = video_uri
        self.aspect_ratio = aspect_ratio
        
        self.window = Window("Glitter Video Player")
        self.window.connect("destroy", self.destroy)

        self.stage = self.window.get_stage()
        self.stage.connect('notify::width', self.do_resize)
        self.stage.connect('notify::height', self.do_resize)
        
        self.frame = Frame()
        self.stage.add(self.frame)
        self.frame._update_layout()
        
        self.video = Video(video_uri, aspect_ratio)
        self.frame.add(self.video)
        self.video.play()
        
        self.toolbar = Toolbar()
        self.frame.add(self.toolbar)
        self.toolbar.natural_width = 0.8
        #self.toolbar.natural_height = 0.2
        self.toolbar.natural_x = 0.1
        self.toolbar.natural_y = 0.7
        self.toolbar._update_layout()
        
        self.vbox = VBox()
        self.toolbar.pack(self.vbox)
        self.vbox.spacing = 0.1
        
        self.slider = Slider()
        self.vbox.pack(self.slider)
        self.slider.h_offset = 0.1
        
        self.hbox = HBox()
        self.hbox.spacing = 0.1
        self.hbox.h_offset = 0.3
        self.vbox.pack(self.hbox)
        
        self.fbutton1 = FloatingButton(icon="test.svg", label="Play")
        self.hbox.pack(self.fbutton1)

        self.fbutton2 = FloatingButton(icon="test.svg", label="Pause")
        self.hbox.pack(self.fbutton2)
        
        self.fbutton3 = FloatingButton(icon="test.svg", label="Stop")
        self.hbox.pack(self.fbutton3)
        
        self.window.show_all()
        gtk.main()
        
    def destroy(self, widget, data=None):
        gtk.main_quit()

    def do_resize(self, stage, event):
        self.frame._update_layout()
        #print self.vbox.get_heightu()
        
if __name__ == '__main__':
    if len(sys.argv) != 3:
        print "Missing arguments, correct usage is: "
        print "python video.py video_file_uri [ex: glitter.mov] " + \
              "mode [native, widescreen, tv, smart]"
        sys.exit(1)
    else:
        VideoPlayer(sys.argv[1], sys.argv[2])
